% Declare that this style file requires at least LaTeX version 2e.
\NeedsTeXFormat{LaTeX2e}

% Provide the name of your page, the date it was last updated, and a comment about what it's used for

% test whether main document provides options. 
\ProvidesClass{OML}
%\LoadClassWithOptions{scrartcl} % ukoliko u glavnom dokumentu zelimo spec. opcije
\LoadClass[b5paper,twoside,openleft,10pt,DIV=10]{scrartcl}


% Now paste your code from the preamble here


\usepackage[utf8]{inputenc}
\usepackage[T1]{fontenc}
%\usepackage{alltt}
\usepackage{multicol}
\usepackage{titling}
\usepackage{abstract}

\usepackage[affil-it]{authblk}
\usepackage{lastpage}

\usepackage[croatian]{babel}
\usepackage{xcolor}
\usepackage{booktabs}

\usepackage[pdftex]{graphicx}
\usepackage{epstopdf}

\usepackage [linkcolor=blue]{hyperref}
\usepackage{listings}
\usepackage{array}
\usepackage{fancybox}
\usepackage{xtab}
\usepackage{tabulary}
\usepackage{calc}
%\usepackage{hyperref}

\usepackage{amsfonts}
\usepackage{tikz}
\usepackage{verbatim}
\usepackage{wrapfig}
\usepackage{clrscode}
\usepackage{marginnote}

% programming code 
\usepackage{listings}

% font style
\addtokomafont{disposition}{\rmfamily}

% geometry of paper
\usepackage[scale={0.65,0.7}]{geometry}
\usepackage{subfigure}

\usepackage{thmtools}
\usepackage[amsthm,thmmarks]{ntheorem}

%\usepackage{amsthm}
\usepackage{amssymb,amsmath}


\let\oldtitle\title
\renewcommand{\title}[1]{\oldtitle{#1}\def\titletext{#1}}

\usepackage{fancyhdr}
\usepackage{authoraftertitle}


\fancypagestyle{OMLtitle_hdr}{
\fancyhf{}
\renewcommand{\headrulewidth}{0pt}
\fancyhead[L]{\textsc{Osje\v{c}ki matemati\v{c}ki list 19 (2019), \pageref*{FirstPage}--\pageref*{LastPage}}}
}

\fancypagestyle{OMLaktivnosti}{
\fancyhf{}
\renewcommand{\headrulewidth}{0pt}
\fancyhead[C]{\scshape Aktivnosti}

\fancyfoot[OR]{\thepage}
\fancyfoot[EL]{\thepage}
}

\fancypagestyle{OMLhdr}{ %
\fancyhf{}
\renewcommand{\headrulewidth}{0pt}

\makeatletter
\fancyhead[EC]{\scshape{\let\thanks\@gobble\MyAuthor}}
\fancyhead[OC]{\scshape \MyTitle}
\pagestyle{fancy}
\makeatother

\fancyfoot[OR]{\thepage}
\fancyfoot[EL]{\thepage}
}



\usepackage{lipsum}

% font types
\usepackage[sc]{mathpazo} % use mathpazo for math fonts
\usepackage{tgpagella} % but use tgpagella as main font

%\usetikzlibrary{arrows,decorations.pathmorphing,backgrounds,fit}

% math commands


\lstloadlanguages{C++}
\lstset{language=C++,                            %
   basicstyle={\ttfamily \footnotesize},
    keywordstyle=\color[rgb]{0,0.5,1},                    %
    commentstyle=\color[rgb]{0.5,0.5,0.5},    %
    stringstyle=\color[rgb]{0.627,0.126,0.941},%
    showstringspaces=false,
    breaklines
}

%\theoremstyle{plain} \theorembodyfont{\upshape}
\newtheorem{lema}{Lema}[section]
\newtheorem{teorem}{Teorem}[section]
\newtheorem{korolar}{Korolar}[section]
\newtheorem{propozicija}{Propozicija}[section]

\theoremstyle{remark}
\newtheorem{zadatak}{Zadatak}
\newtheorem{primjer}{Primjer}
\newtheorem{napomena}{Napomena}[section]

\theoremstyle{definition}
\newtheorem{definicija}{Definicija}[section]
\theoremstyle{plain}


\makeatletter
\newenvironment{rjesenje}
               {
                \def\@addpunct##1{}%
                \renewcommand\proofSymbol{\ensuremath{\blacktriangleleft}}
                \begin{proof}[\slshape Rješenje]}%
               {\end{proof}%
                
				}
%\makeatother




% Graffiti as in GKP's book "Concrete Mathematics"
% thanks to Lorenzo Pantieri and Enrico Gregorio
\def\graffito@setup{%
   \slshape\footnotesize%
   \parindent=0pt \lineskip=0pt \lineskiplimit=0pt %
   \tolerance=2000 \hyphenpenalty=300 \exhyphenpenalty=300%
   \doublehyphendemerits=100000%
   \finalhyphendemerits=\doublehyphendemerits}
%\DeclareRobustCommand{\graffito}[1]{\marginpar%
% [\graffito@setup\raggedleft\hspace{0pt}{#1}]%
% {\graffito@setup\raggedright\hspace{0pt}{#1}}}
\let\oldmarginpar\marginpar
\renewcommand{\marginpar}[1]{\oldmarginpar%
 [\graffito@setup\scriptsize\raggedleft\hspace{0pt}{#1}]%
 {\graffito@setup\scriptsize\raggedright\hspace{0pt}{#1}}}



% title
\newcommand{\Title}[1]
{

   \begin{center}
   \Large
   #1
   \end{center}
}


% polyabstract
\newenvironment{Abstract}[1]
  {\renewcommand{\abstractname}{#1}\begin{abstract}}
  {\end{abstract}}

% keywords
\newcommand{\keywords}[2]
{
   \parbox{0.9\linewidth}{
      \textbf{#1}:~\emph{#2}
	}   
   

}



% marginpar with picture and comment
\newcommand{\marginimg}[2]
{
\marginpar{
	    \includegraphics[width=1.5cm]{#1} \rule{0px}{10px}\\  #2 
	  
	    }
}


